==> kubernetes-model-storageclass-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/storage/v1beta1/CSIDriverListBuilder.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSIDriverListBuilder extends io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverListFluentImpl<io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverList,io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverListBuilder>{
  public CSIDriverListBuilder() {
    this(false);
  }
  public CSIDriverListBuilder(java.lang.Boolean validationEnabled) {
    this(new CSIDriverList(), validationEnabled);
  }
  public CSIDriverListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverListFluent<?> fluent) {
    this(fluent, false);
  }
  public CSIDriverListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSIDriverList(), validationEnabled);
  }
  public CSIDriverListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverListFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverList instance) {
    this(fluent, instance, false);
  }
  public CSIDriverListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverListFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSIDriverListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverList instance) {
    this(instance,false);
  }
  public CSIDriverListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverList build() {
    CSIDriverList buildable = new CSIDriverList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSIDriverListBuilder that = (CSIDriverListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-storageclass-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/storage/v1beta1/CSIDriverListBuilder.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CSIDriverListBuilder extends CSIDriverListFluentImpl<CSIDriverListBuilder> implements VisitableBuilder<CSIDriverList,CSIDriverListBuilder>{
  public CSIDriverListBuilder() {
    this(false);
  }
  public CSIDriverListBuilder(Boolean validationEnabled) {
    this(new CSIDriverList(), validationEnabled);
  }
  public CSIDriverListBuilder(CSIDriverListFluent<?> fluent) {
    this(fluent, false);
  }
  public CSIDriverListBuilder(CSIDriverListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CSIDriverList(), validationEnabled);
  }
  public CSIDriverListBuilder(CSIDriverListFluent<?> fluent,CSIDriverList instance) {
    this(fluent, instance, false);
  }
  public CSIDriverListBuilder(CSIDriverListFluent<?> fluent,CSIDriverList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSIDriverListBuilder(CSIDriverList instance) {
    this(instance,false);
  }
  public CSIDriverListBuilder(CSIDriverList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  CSIDriverListFluent<?> fluent;
  Boolean validationEnabled;
  public CSIDriverList build() {
    CSIDriverList buildable = new CSIDriverList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
